==> revive-adserver-5.1.0.zip: revive-adserver-5.1.0/lib/max/language/ko/invocation.lang.php <==
<?php

/*
  +---------------------------------------------------------------------------+
  | Revive Adserver                                                           |
  | http://www.revive-adserver.com                                            |
  |                                                                           |
  | Copyright: See the COPYRIGHT.txt file.                                    |
  | License: GPLv2 or later, see the LICENSE.txt file.                        |
  +---------------------------------------------------------------------------+
 */

// Other
$GLOBALS['strCopyToClipboard'] = "클립보드에 복사";
$GLOBALS['strChooseTypeOfInvocation'] = "호출할 배너 종류를 선택하세요.";
$GLOBALS['strChooseTypeOfBannerInvocation'] = "배너 유형을 선택해 주십시오.";

// Measures

// Common Invocation Parameters
$GLOBALS['strInvocationWhat'] = "배너 선택";
$GLOBALS['strInvocationCampaignID'] = "캠페인";
$GLOBALS['strInvocationTarget'] = "대상 프레임";
$GLOBALS['strInvocationSource'] = "소스";
$GLOBALS['strInvocationWithText'] = "배너 밑에 텍스트를 표시합니다.";
$GLOBALS['strInvocationDontShowAgain'] = "같은 페이지에 연속해서 배너를 표시하지 않습니다.";
$GLOBALS['strInvocationTemplate'] = "배너를 템플릿에서 사용할 수 있도록 변수에 저장합니다.";

// Iframe
$GLOBALS['strIFrameRefreshAfter'] = "새로고침 간격";
$GLOBALS['strIframeResizeToBanner'] = "iframe을 배너에 맞게 크기 조정";
$GLOBALS['strIframeMakeTransparent'] = "iframe을 투명하게 설정";
$GLOBALS['strIframeIncludeNetscape4'] = "넷스케이프 4 ilayer 호환";

// PopUp
$GLOBALS['strPopUpStyle'] = "팝업 형식";
$GLOBALS['strPopUpStylePopUp'] = "팝업";
$GLOBALS['strPopUpStylePopUnder'] = "팝언더";
$GLOBALS['strPopUpCreateInstance'] = "팝업이 생성되는 경우";
$GLOBALS['strPopUpImmediately'] = "바로 띄우기";
$GLOBALS['strPopUpOnClose'] = "페이지를 닫을 때";
$GLOBALS['strPopUpAfterSec'] = "후에 ";
$GLOBALS['strAutoCloseAfter'] = "후에 자동으로 닫음";
$GLOBALS['strPopUpTop'] = "격자 배너 위치(top)";
$GLOBALS['strPopUpLeft'] = "격자 배너 위치(left)";
$GLOBALS['strWindowOptions'] = "창 옵션";
$GLOBALS['strShowLocation'] = "위치";

// XML-RPC
$GLOBALS['strXmlRpcLanguage'] = "사용 언어";

// Support for cachebusting code

// IMG invocation selected for tracker with appended code
$GLOBALS['strWarning'] = "경고";

// Local Invocation

==> revive-adserver-6.0.1.zip: revive-adserver-6.0.1/lib/max/language/ko/invocation.lang.php <==
<?php

/*
  +---------------------------------------------------------------------------+
  | Revive Adserver                                                           |
  | http://www.revive-adserver.com                                            |
  |                                                                           |
  | Copyright: See the COPYRIGHT.txt file.                                    |
  | License: GPLv2 or later, see the LICENSE.txt file.                        |
  +---------------------------------------------------------------------------+
 */

// Other
$GLOBALS['strCopyToClipboard'] = "클립보드에 복사";
$GLOBALS['strChooseTypeOfInvocation'] = "호출할 배너 종류를 선택하세요.";
$GLOBALS['strChooseTypeOfBannerInvocation'] = "배너 유형을 선택해 주십시오.";

// Measures

// Common Invocation Parameters
$GLOBALS['strInvocationWhat'] = "배너 선택";
$GLOBALS['strInvocationCampaignID'] = "캠페인";
$GLOBALS['strInvocationTarget'] = "대상 프레임";
$GLOBALS['strInvocationSource'] = "소스";
$GLOBALS['strInvocationWithText'] = "배너 밑에 텍스트를 표시합니다.";
$GLOBALS['strInvocationDontShowAgain'] = "같은 페이지에 연속해서 배너를 표시하지 않습니다.";
$GLOBALS['strInvocationTemplate'] = "배너를 템플릿에서 사용할 수 있도록 변수에 저장합니다.";

// Iframe
$GLOBALS['strIFrameRefreshAfter'] = "새로고침 간격";
$GLOBALS['strIframeMakeTransparent'] = "iframe을 투명하게 설정";

// PopUp
$GLOBALS['strPopUpStyle'] = "팝업 형식";
$GLOBALS['strPopUpCreateInstance'] = "팝업이 생성되는 경우";
$GLOBALS['strPopUpImmediately'] = "바로 띄우기";
$GLOBALS['strPopUpOnClose'] = "페이지를 닫을 때";
$GLOBALS['strPopUpAfterSec'] = "후에 ";
$GLOBALS['strAutoCloseAfter'] = "후에 자동으로 닫음";
$GLOBALS['strPopUpTop'] = "격자 배너 위치(top)";
$GLOBALS['strPopUpLeft'] = "격자 배너 위치(left)";
$GLOBALS['strWindowOptions'] = "창 옵션";
$GLOBALS['strShowLocation'] = "위치";
$GLOBALS['strShowStatus'] = "상태";

// Support for cachebusting code

// IMG invocation selected for tracker with appended code
$GLOBALS['strWarning'] = "경고";
